========
Customer
========

The customer app bundles communication with customers. This includes models
to record product alerts and sent emails. It also contains the views that
allow a customer to manage their data (profile information, shipping addresses,
etc.)

Abstract models
---------------

.. automodule:: oscar.apps.customer.abstract_models
    :members:

Forms
-----

.. automodule:: oscar.apps.customer.forms
    :members:

Views
-----

.. automodule:: oscar.apps.customer.views
    :members:
